extraTextures property
Texture slots beyond the standard five, by sampler name.
Implementation
final Map<String, TextureBinding> extraTextures;
Texture slots beyond the standard five, by sampler name.
final Map<String, TextureBinding> extraTextures;