ComputePipelineHandle class final
A compiled compute stage, ready to dispatch.
Constructors
- ComputePipelineHandle({required Object backend, required ShaderHandle shader})
Properties
- backend → Object
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shader → ShaderHandle
-
The stage it was built from.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited