VertexLayoutSpec class final
Every buffer a pipeline reads vertices from, in slot order.
Constructors
-
VertexLayoutSpec(List<
BufferLayout> buffers) -
const
Properties
-
buffers
→ List<
BufferLayout> -
Slot n is
buffers[n], and there are no gaps — see the library comment.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited